/*******************************************************************************************/
/**                                                                                       **/
/** COPYRIGHT (C) 2019, Systemyde International Corporation, ALL RIGHTS RESERVED          **/
/**                                                                                       **/
/** gnss board                                                        Rev 0.0  09/23/2019 **/
/**                                                                                       **/
/*******************************************************************************************/
module gnss_brd (data_bus, isa_bus, fi_bus, spi_csn, spi_sck, spi_so, osc_in, ph1, ph2,
                 pwr_up, pwo, spi_si, sync);

  inout         data_bus;      /* memory/peripheral data bus                          bus  */
  inout         isa_bus;       /* instruction address/data bus                        bus  */
  input         osc_in;        /* 32768Hz clock input                               32khz  */
  input         ph1;           /* clock phase 1                                       bus  */
  input         ph2;           /* clock phase 2                                       bus  */
  input         pwr_up;        /* power on reset                                      por  */
  input         pwo;           /* power off                                           bus  */
  input         spi_si;        /* spi serial input: rx from gnss receiver             ffc  */
  input         sync;          /* synchronization                                     bus  */
  output        fi_bus;        /* flag bus                                            bus  */
  output        spi_csn;       /* spi chip select: gnss enable                        ffc  */
  output        spi_sck;       /* spi serial clock                                    ffc  */
  output        spi_so;        /* spi serial output: tx to gnss receiver              ffc  */

  /*****************************************************************************************/
  /* signal declarations                                                                   */
  /*****************************************************************************************/
  wire        data_drv;                                    /* memory/peripheral data bus   */
  wire        data_out;                                    /* memory/peripheral data bus   */
  wire        fi_bus;                                      /* flag bus                     */
  wire        fi_drv;                                      /* flag bus                     */
  wire        fi_out;                                      /* flag bus                     */
  wire        isa_drv;                                     /* drive isa_bus                */
  wire        isa_out;                                     /* data: isa_bus                */
  wire        spi_csn;                                     /* gnss enable                  */
  wire        spi_sck;                                     /*                              */
  wire        spi_so;                                      /*  tx to gnss receiver         */

  /*****************************************************************************************/
  /* bus drivers                                                                           */
  /*****************************************************************************************/
  assign data_bus = (data_drv) ? data_out : 1'bz;
  assign isa_bus  = (isa_drv)  ? isa_out  : 1'bz;
  assign fi_bus   = (fi_drv)   ? fi_out   : 1'bz;

  /*****************************************************************************************/
  /* fpga                                                                                  */
  /*****************************************************************************************/
  gnss_top FPGA  ( .data_drv(data_drv), .data_out(data_out), .debug_out(), .fi_drv(fi_drv),
                   .fi_out(fi_out), .isa_drv(isa_drv), .isa_out(isa_out), .spi_csn(spi_csn),
                   .spi_sck(spi_sck), .spi_so(spi_so), .data_bus(data_bus),
                   .debug_ctl(3'b111), .isa_bus(isa_bus), .osc_in(osc_in), .ph1(ph1),
                   .ph2(ph2), .pwr_up(pwr_up), .pwo(pwo), .spi_si(spi_si), .sync(sync) );

  endmodule





