/*******************************************************************************************/
/**                                                                                       **/
/** COPYRIGHT (C) 2018, SYSTEMYDE INTERNATIONAL CORPORATION, ALL RIGHTS RESERVED          **/
/**                                                                                       **/
/** 512x8 ram                                                         Rev 0.0  05/02/2018 **/
/**                                                                                       **/
/*******************************************************************************************/
module ram_512x8 (RADDR, RCLK, RCLKE, RE, RDATA, WADDR, WCLK, WCLKE, WE, WDATA);

  input         RCLK;                                      /* read clock                   */
  input         RCLKE;                                     /* read clock enable            */
  input         RE;                                        /* read enable                  */
  input         WCLK;                                      /* write clock                  */
  input         WCLKE;                                     /* write clock enable           */
  input         WE;                                        /* write enable                 */
  input   [8:0] RADDR;                                     /* read address                 */
  input   [8:0] WADDR;                                     /* write address                */
  input   [7:0] WDATA;                                     /* write data                   */

  output  [7:0] RDATA;                                     /* read data                    */

  /*****************************************************************************************/
  /* signal declarations                                                                   */
  /*****************************************************************************************/
  integer i;

  reg           ram_0 [0:511];                             /* column 0                     */
  reg           ram_1 [0:511];                             /* column 1                     */
  reg           ram_2 [0:511];                             /* column 2                     */
  reg           ram_3 [0:511];                             /* column 3                     */
  reg           ram_4 [0:511];                             /* column 4                     */
  reg           ram_5 [0:511];                             /* column 5                     */
  reg           ram_6 [0:511];                             /* column 6                     */
  reg           ram_7 [0:511];                             /* column 7                     */

  reg     [7:0] RDATA;                                     /* read data                    */

  /*****************************************************************************************/
  /* memory initialization                                                                 */
  /*****************************************************************************************/
  parameter INIT_0 = 512'h0;
  parameter INIT_1 = 512'h0;
  parameter INIT_2 = 512'h0;
  parameter INIT_3 = 512'h0;
  parameter INIT_4 = 512'h0;
  parameter INIT_5 = 512'h0;
  parameter INIT_6 = 512'h0;
  parameter INIT_7 = 512'h0;

  wire  [511:0] init_0 = INIT_0;
  wire  [511:0] init_1 = INIT_1;
  wire  [511:0] init_2 = INIT_2;
  wire  [511:0] init_3 = INIT_3;
  wire  [511:0] init_4 = INIT_4;
  wire  [511:0] init_5 = INIT_5;
  wire  [511:0] init_6 = INIT_6;
  wire  [511:0] init_7 = INIT_7;

  initial begin
    for (i=0; i<512; i=i+1) begin
      ram_0[i] = init_0[i]; 
      ram_1[i] = init_1[i]; 
      ram_2[i] = init_2[i]; 
      ram_3[i] = init_3[i]; 
      ram_4[i] = init_4[i]; 
      ram_5[i] = init_5[i]; 
      ram_6[i] = init_6[i]; 
      ram_7[i] = init_7[i]; 
      end
    end

  /*****************************************************************************************/
  /* write                                                                                 */
  /*****************************************************************************************/
  always @ (posedge WCLK) begin
    if (WCLKE && WE) begin
      ram_7[WADDR] <= WDATA[7];
      ram_6[WADDR] <= WDATA[6];
      ram_5[WADDR] <= WDATA[5];
      ram_4[WADDR] <= WDATA[4];
      ram_3[WADDR] <= WDATA[3];
      ram_2[WADDR] <= WDATA[2];
      ram_1[WADDR] <= WDATA[1];
      ram_0[WADDR] <= WDATA[0];
      end
    end

  /*****************************************************************************************/
  /* read                                                                                  */
  /*****************************************************************************************/
  always @ (posedge RCLK) begin
    if (RCLKE && RE) begin
      RDATA <= {ram_7[RADDR], ram_6[RADDR], ram_5[RADDR], ram_4[RADDR],
                ram_3[RADDR], ram_2[RADDR], ram_1[RADDR], ram_0[RADDR]};
      end
    end

  endmodule





